@@ -1,16 +1,20 @@
-import logging
-
+"""Sync intellifire module."""
 import requests
+
 from intellifire4py.model import IntellifirePollData
 
-class Intellifire:
 
-    def __init__(self, ip) -> None:
+class Intellifire:
+    """Synchronous intellifire poller."""
+
+    def __init__(self, ip: str) -> None:
+        """Initialize the class."""
         self.ip = ip
 
-        self.__data: IntellifirePollData = None
+        self.__data: IntellifirePollData = None  # type: ignore
 
-    def poll(self):
+    def poll(self) -> None:
+        """Poll the device for data."""
         try:
             response = requests.get("http://" + self.ip + "/poll")
             if response.status_code == 404:
@@ -19,15 +23,17 @@ class Intellifire:
 
             print(response.json())
             self.__data = IntellifirePollData(**response.json())
-        except ConnectionError as e:
+        except ConnectionError:
             raise ConnectionError("ConnectionError - host not found")
 
     @property
     def data(self) -> IntellifirePollData:
+        """Return Intellifire data."""
         return self.__data
 
 
-def main():
+def main() -> None:
+    """Run main function."""
     print("Starting Intellifre Parser")
     fire = Intellifire("192.168.1.65")
     # Poll the fire
