@@ -1,15 +1,15 @@
-
 from typing import List
 
 from pydantic import BaseModel, Field
 
+
 class IntellifirePollData(BaseModel):
     name: str
     serial: str
     temperature_c: int = Field(alias="temperature")
     battery: int
     pilot_on: bool = Field(alias="pilot")
-    light_on: bool = Field(alias="light")
+    light_level: int = Field(alias="light")
     flameheight: int = Field(alias="height")
     fanspeed: int
     is_hot: bool = Field(alias="hot")
@@ -37,10 +37,49 @@ class IntellifirePollData(BaseModel):
         return (self.temperature_c * 9 / 5) + 32
 
     @property
-    def thermostat_setpoint_c(self) -> int:
+    def thermostat_setpoint_c(self) -> float:
         return self.raw_thermostat_setpoint / 100
 
     @property
-    def thermostat_setpoint_f(self) -> int:
+    def thermostat_setpoint_f(self) -> float:
         return (self.raw_thermostat_setpoint / 100 * 9 / 5) + 32
 
+
+class UDPResponse(BaseModel):
+    mac: str
+    bssid: str
+    channel: int
+    ip: str
+    ssid: str
+    rssi: int
+    remote_terminal_port: int
+    time: int
+    version: str
+    uuid: str
+
+
+class IntellifireLocationDetails(BaseModel):
+    location_id: str
+    location_name: str
+    wifi_essid: str
+    wifi_password: str
+    postal_code: str
+    user_class: int
+
+
+class IntellifireLocations(BaseModel):
+    locations: List[IntellifireLocationDetails]
+    email_notifications_enabled: int
+
+
+class IntellifireFireplace(BaseModel):
+    serial: str
+    brand: str
+    name: str
+    apikey: str
+    power: str
+
+
+class IntellifireFireplaces(BaseModel):
+    location_name: str
+    fireplaces: List[IntellifireFireplace]
